@@ -1,3 +1,11 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 /*
  *  Shamelessly duplicated from the fetchmail public sources
  *  for use by the Squid Project under GNU Public License.
@@ -5,15 +13,13 @@
  * Update/Maintenance History:
  *
  *    15-Aug-2007 : Copied from fetchmail 6.3.8
- *			- added protection around libray headers
+ *          - added protection around libray headers
  *
  *    16-Aug-2007 : Altered configure checks
  *                  Un-hacked slightly to use system gethostbyname()
  *
  *    06-Oct-2007 : Various fixes to allow the build on MinGW
  *
- * Squid CVS $Id$
- *
  *  Original License and code follows.
  */
 #include "squid.h"
@@ -307,18 +313,18 @@ xgai_strerror (int ecode)
 {
     static const char *eai_descr[] = {
         "no error",
-        "address family for nodename not supported",	/* EAI_ADDRFAMILY */
-        "temporary failure in name resolution",		/* EAI_AGAIN */
-        "invalid value for ai_flags",	 		/* EAI_BADFLAGS */
-        "non-recoverable failure in name resolution",	/* EAI_FAIL */
-        "ai_family not supported",			/* EAI_FAMILY */
-        "memory allocation failure",			/* EAI_MEMORY */
-        "no address associated with nodename",		/* EAI_NODATA */
-        "nodename nor servname provided, or not known",	/* EAI_NONAME */
-        "servname not supported for ai_socktype",		/* EAI_SERVICE */
-        "ai_socktype not supported",			/* EAI_SOCKTYPE */
-        "system error returned in errno",			/* EAI_SYSTEM */
-        "argument buffer overflow",			/* EAI_OVERFLOW */
+        "address family for nodename not supported",    /* EAI_ADDRFAMILY */
+        "temporary failure in name resolution",     /* EAI_AGAIN */
+        "invalid value for ai_flags",           /* EAI_BADFLAGS */
+        "non-recoverable failure in name resolution",   /* EAI_FAIL */
+        "ai_family not supported",          /* EAI_FAMILY */
+        "memory allocation failure",            /* EAI_MEMORY */
+        "no address associated with nodename",      /* EAI_NODATA */
+        "nodename nor servname provided, or not known", /* EAI_NONAME */
+        "servname not supported for ai_socktype",       /* EAI_SERVICE */
+        "ai_socktype not supported",            /* EAI_SOCKTYPE */
+        "system error returned in errno",           /* EAI_SYSTEM */
+        "argument buffer overflow",         /* EAI_OVERFLOW */
     };
 
     if (ecode < 0 || ecode > (int) (sizeof eai_descr/ sizeof eai_descr[0]))
@@ -327,3 +333,4 @@ xgai_strerror (int ecode)
 }
 
 #endif /* HAVE_GETADDRINFO */
+
