@@ -1,6 +1,10 @@
-#ifndef SQUID_CONFIG_H
-#include "config.h"
-#endif
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
 
 #ifndef _INC_INET_NTOP_H
 #define _INC_INET_NTOP_H
@@ -21,3 +25,4 @@ SQUIDCEXTERN const char * xinet_ntop(int af, const void *src, char *dst, size_t
 
 #endif
 #endif /* _INC_INET_NTOP_H */
+
