@@ -1,4 +1,10 @@
-#include "config.h"
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
 
 /*
  * allowusers.c
@@ -10,19 +16,21 @@
  * The code originated from denyusers.c.
  */
 
-#include <stdlib.h>
+#include "squid.h"
+#include "msntauth.h"
+#include "usersfile.h"
+
+#include <cstdlib>
+#include <cstring>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/param.h>
-#include <string.h>
-#include "usersfile.h"
-#include "msntauth.h"
 
 static usersfile AllowUsers;
 static int init = 0;
 
 /* shared */
-char Allowuserpath[MAXPATHLEN];	/* MAXPATHLEN defined in param.h */
+char Allowuserpath[MAXPATHLEN]; /* MAXPATHLEN defined in param.h */
 
 int
 Read_allowusers(void)
@@ -48,3 +56,4 @@ Check_forallowchange(void)
 {
     Check_forfilechange(&AllowUsers);
 }
+
