@@ -1,10 +1,15 @@
 /*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
- *
- *
- * ldap_backend.c
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
+/*
  * AUTHOR: Flavio Pescuma, MARA Systems AB <flavio@marasystems.com>
  */
+
 #include "squid.h"
 #include "util.h"
 
@@ -12,7 +17,7 @@
 
 #include "ldap_backend.h"
 
-#if _SQUID_MSWIN_		/* Native Windows port and MinGW */
+#if _SQUID_WINDOWS_ && !_SQUID_CYGWIN_
 
 #define snprintf _snprintf
 #include <windows.h>
@@ -230,7 +235,7 @@ retrysrch:
                     ldap_msgfree(res);
                     /* try to connect to the LDAP server agin, maybe my persisten conexion failed. */
                     if (!retry) {
-                        retry++;
+                        ++retry;
                         ldap_unbind(ld);
                         ld = NULL;
                         ldapconnect();
@@ -272,7 +277,7 @@ retrydnattr:
                     password = *value;
                     break;
                 }
-                value++;
+                ++value;
             }
             debug("password: %s\n", password);
             if (password)
@@ -284,7 +289,7 @@ retrydnattr:
             fprintf(stderr, PROGRAM_NAME " WARNING, LDAP error '%s'\n", ldap_err2string(rc));
             /* try to connect to the LDAP server agin, maybe my persisten conexion failed. */
             if (!retry) {
-                retry++;
+                ++retry;
                 ldap_unbind(ld);
                 ld = NULL;
                 ldapconnect();
@@ -296,8 +301,6 @@ retrydnattr:
     return NULL;
 }
 
-
-
 static void
 ldapconnect(void)
 {
@@ -306,7 +309,7 @@ ldapconnect(void)
     /* On Windows ldap_start_tls_s is available starting from Windows XP,
      * so we need to bind at run-time with the function entry point
      */
-#if _SQUID_MSWIN_
+#if _SQUID_WINDOWS_
     if (use_tls) {
 
         HMODULE WLDAP32Handle;
@@ -335,7 +338,7 @@ ldapconnect(void)
                             sslpath);
                     exit(1);
                 } else {
-                    sslinit++;
+                    ++sslinit;
                 }
                 if ((ld = ldapssl_init(ldapServer, port, 1)) == NULL) {
                     fprintf(stderr, "\nUnable to connect to SSL LDAP server: %s port:%d\n",
@@ -413,21 +416,21 @@ LDAPArguments(int argc, char **argv)
                 value = argv[1] + 2;
             } else if (argc > 2) {
                 value = argv[2];
-                argv++;
-                argc--;
+                ++argv;
+                --argc;
             } else
                 value = "";
             break;
         }
-        argv++;
-        argc--;
+        ++argv;
+        --argc;
         switch (option) {
         case 'H':
 #if !HAS_URI_SUPPORT
             fprintf(stderr, "ERROR: Your LDAP library does not have URI support\n");
             return 1;
 #endif
-            /* Fall thru to -h */
+        /* Fall thru to -h */
         case 'h':
             if (ldapServer) {
                 int len = strlen(ldapServer) + 1 + strlen(value) + 1;
@@ -564,8 +567,8 @@ LDAPArguments(int argc, char **argv)
         } else {
             ldapServer = xstrdup(value);
         }
-        argc--;
-        argv++;
+        --argc;
+        ++argv;
     }
 
     if (!ldapServer)
@@ -657,3 +660,4 @@ LDAPHHA1(RequestData * requestData)
     }
 
 }
+
