@@ -1,3 +1,11 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 /*
  * ext_ad_group_acl: lookup group membership in a Windows
  * Active Directory domain
@@ -57,7 +65,7 @@
  *
  */
 
-#include "config.h"
+#include "squid.h"
 #include "helpers/defines.h"
 #include "include/util.h"
 
@@ -66,20 +74,13 @@
 int _wcsicmp(const wchar_t *, const wchar_t *);
 #endif
 
-#if HAVE_STDIO_H
-#include <stdio.h>
-#endif
-#if HAVE_CTYPE_H
-#include <ctype.h>
-#endif
-#if HAVE_STRING_H
-#include <string.h>
-#endif
+#undef assert
+#include <cassert>
+#include <cctype>
+#include <cstring>
 #if HAVE_GETOPT_H
 #include <getopt.h>
 #endif
-#undef assert
-#include <assert.h>
 #include <windows.h>
 #include <objbase.h>
 #include <initguid.h>
@@ -112,7 +113,6 @@ int User_Groups_Count = 0;
 wchar_t *My_NameTranslate(wchar_t *, int, int);
 char *Get_WIN32_ErrorMessage(HRESULT);
 
-
 void
 CloseCOM(void)
 {
@@ -120,7 +120,6 @@ CloseCOM(void)
         CoUninitialize();
 }
 
-
 HRESULT
 GetLPBYTEtoOctetString(VARIANT * pVar, LPBYTE * ppByte)
 {
@@ -151,7 +150,6 @@ GetLPBYTEtoOctetString(VARIANT * pVar, LPBYTE * ppByte)
     return hr;
 }
 
-
 wchar_t *
 Get_primaryGroup(IADs * pUser)
 {
@@ -190,7 +188,7 @@ Get_primaryGroup(IADs * pUser)
         CoTaskMemFree(pByte);
 
         *(strrchr(szSID, '-') + 1) = '\0';
-        sprintf(tmpSID, "%s%u", szSID, User_primaryGroupID);
+        snprintf(tmpSID, sizeof(tmpSID)-1, "%s%u", szSID, User_primaryGroupID);
 
         wcsize = MultiByteToWideChar(CP_ACP, 0, tmpSID, -1, wc, 0);
         wc = (wchar_t *) xmalloc(wcsize * sizeof(wchar_t));
@@ -210,7 +208,6 @@ Get_primaryGroup(IADs * pUser)
     return result;
 }
 
-
 char *
 Get_WIN32_ErrorMessage(HRESULT hr)
 {
@@ -225,7 +222,6 @@ Get_WIN32_ErrorMessage(HRESULT hr)
     return WIN32_ErrorMessage;
 }
 
-
 wchar_t *
 My_NameTranslate(wchar_t * name, int in_format, int out_format)
 {
@@ -281,7 +277,6 @@ My_NameTranslate(wchar_t * name, int in_format, int out_format)
     return wc;
 }
 
-
 wchar_t *
 GetLDAPPath(wchar_t * Base_DN, int query_mode)
 {
@@ -298,7 +293,6 @@ GetLDAPPath(wchar_t * Base_DN, int query_mode)
     return wc;
 }
 
-
 char *
 GetDomainName(void)
 {
@@ -349,7 +343,6 @@ GetDomainName(void)
     return DomainName;
 }
 
-
 int
 add_User_Group(wchar_t * Group)
 {
@@ -358,24 +351,23 @@ add_User_Group(wchar_t * Group)
     if (User_Groups_Count == 0) {
         User_Groups = (wchar_t **) xmalloc(sizeof(wchar_t *));
         *User_Groups = NULL;
-        User_Groups_Count++;
+        ++User_Groups_Count;
     }
     array = User_Groups;
     while (*array) {
         if (wcscmp(Group, *array) == 0)
             return 0;
-        array++;
+        ++array;
     }
     User_Groups = (wchar_t **) xrealloc(User_Groups, sizeof(wchar_t *) * (User_Groups_Count + 1));
     User_Groups[User_Groups_Count] = NULL;
     User_Groups[User_Groups_Count - 1] = (wchar_t *) xmalloc((wcslen(Group) + 1) * sizeof(wchar_t));
     wcscpy(User_Groups[User_Groups_Count - 1], Group);
-    User_Groups_Count++;
+    ++User_Groups_Count;
 
     return 1;
 }
 
-
 /* returns 0 on match, -1 if no match */
 static int
 wccmparray(const wchar_t * str, const wchar_t ** array)
@@ -384,17 +376,16 @@ wccmparray(const wchar_t * str, const wchar_t ** array)
         debug("Windows group: %S, Squid group: %S\n", str, *array);
         if (wcscmp(str, *array) == 0)
             return 0;
-        array++;
+        ++array;
     }
     return -1;
 }
 
-
 /* returns 0 on match, -1 if no match */
 static int
 wcstrcmparray(const wchar_t * str, const char **array)
 {
-    WCHAR wszGroup[GNLEN + 1];	// Unicode Group
+    WCHAR wszGroup[GNLEN + 1];  // Unicode Group
 
     while (*array) {
         MultiByteToWideChar(CP_ACP, 0, *array,
@@ -402,12 +393,11 @@ wcstrcmparray(const wchar_t * str, const char **array)
         debug("Windows group: %S, Squid group: %S\n", str, wszGroup);
         if ((use_case_insensitive_compare ? _wcsicmp(str, wszGroup) : wcscmp(str, wszGroup)) == 0)
             return 0;
-        array++;
+        ++array;
     }
     return -1;
 }
 
-
 HRESULT
 Recursive_Memberof(IADs * pObj)
 {
@@ -487,7 +477,6 @@ Recursive_Memberof(IADs * pObj)
     return hr;
 }
 
-
 static wchar_t **
 build_groups_DN_array(const char **array, char *userdomain)
 {
@@ -519,25 +508,24 @@ build_groups_DN_array(const char **array, char *userdomain)
         MultiByteToWideChar(CP_ACP, 0, Group, -1, wc, wcsize);
         *entry = My_NameTranslate(wc, source_group_format, ADS_NAME_TYPE_1779);
         safe_free(wc);
-        array++;
+        ++array;
         if (*entry == NULL) {
             debug("build_groups_DN_array: cannot get DN for '%s'.\n", Group);
             continue;
         }
-        entry++;
+        ++entry;
     }
     *entry = NULL;
     return wc_array;
 }
 
-
 /* returns 1 on success, 0 on failure */
 int
 Valid_Local_Groups(char *UserName, const char **Groups)
 {
     int result = 0;
     char *Domain_Separator;
-    WCHAR wszUserName[UNLEN + 1];	/* Unicode user name */
+    WCHAR wszUserName[UNLEN + 1];   /* Unicode user name */
 
     LPLOCALGROUP_USERS_INFO_0 pBuf;
     LPLOCALGROUP_USERS_INFO_0 pTmpBuf;
@@ -583,7 +571,7 @@ Valid_Local_Groups(char *UserName, const char **Groups)
      */
     if (nStatus == NERR_Success) {
         if ((pTmpBuf = pBuf) != NULL) {
-            for (i = 0; i < dwEntriesRead; i++) {
+            for (i = 0; i < dwEntriesRead; ++i) {
                 assert(pTmpBuf != NULL);
                 if (pTmpBuf == NULL) {
                     result = 0;
@@ -593,8 +581,8 @@ Valid_Local_Groups(char *UserName, const char **Groups)
                     result = 1;
                     break;
                 }
-                pTmpBuf++;
-                dwTotalCount++;
+                ++pTmpBuf;
+                ++dwTotalCount;
             }
         }
     } else {
@@ -609,13 +597,12 @@ Valid_Local_Groups(char *UserName, const char **Groups)
     return result;
 }
 
-
 /* returns 1 on success, 0 on failure */
 int
 Valid_Global_Groups(char *UserName, const char **Groups)
 {
     int result = 0;
-    WCHAR wszUser[DNLEN + UNLEN + 2];	/* Unicode user name */
+    WCHAR wszUser[DNLEN + UNLEN + 2];   /* Unicode user name */
     char NTDomain[DNLEN + UNLEN + 2];
 
     char *domain_qualify = NULL;
@@ -629,7 +616,7 @@ Valid_Global_Groups(char *UserName, const char **Groups)
 
     strncpy(NTDomain, UserName, sizeof(NTDomain));
 
-    for (j = 0; j < strlen(NTV_VALID_DOMAIN_SEPARATOR); j++) {
+    for (j = 0; j < strlen(NTV_VALID_DOMAIN_SEPARATOR); ++j) {
         if ((domain_qualify = strchr(NTDomain, NTV_VALID_DOMAIN_SEPARATOR[j])) != NULL)
             break;
     }
@@ -705,7 +692,7 @@ Valid_Global_Groups(char *UserName, const char **Groups)
                 result = 1;
                 break;
             }
-            tmp++;
+            ++tmp;
         }
     } else
         debug("Valid_Global_Groups: ADsGetObject for %S failed, ERROR: %s\n", User_LDAP_path, Get_WIN32_ErrorMessage(hr));
@@ -716,14 +703,14 @@ Valid_Global_Groups(char *UserName, const char **Groups)
     tmp = wszGroups;
     while (*tmp) {
         safe_free(*tmp);
-        tmp++;
+        ++tmp;
     }
     safe_free(wszGroups);
 
     tmp = User_Groups;
     while (*tmp) {
         safe_free(*tmp);
-        tmp++;
+        ++tmp;
     }
     safe_free(User_Groups);
     User_Groups_Count = 0;
@@ -769,18 +756,17 @@ process_options(int argc, char *argv[])
             exit(0);
         case '?':
             opt = optopt;
-            /* fall thru to default */
+        /* fall thru to default */
         default:
             fprintf(stderr, "%s: FATAL: Unknown option: -%c. Exiting\n", program_name, opt);
             usage(argv[0]);
             exit(1);
-            break;		/* not reached */
+            break;      /* not reached */
         }
     }
     return;
 }
 
-
 int
 main(int argc, char *argv[])
 {
@@ -791,7 +777,7 @@ main(int argc, char *argv[])
     const char *groups[512];
     int n;
 
-    if (argc > 0) {		/* should always be true */
+    if (argc > 0) {     /* should always be true */
         program_name = strrchr(argv[0], '/');
         if (program_name == NULL)
             program_name = argv[0];
@@ -824,7 +810,6 @@ main(int argc, char *argv[])
 
     atexit(CloseCOM);
 
-
     /* Main Loop */
     while (fgets(buf, HELPER_INPUT_BUFFER, stdin)) {
         if (NULL == strchr(buf, '\n')) {
@@ -839,9 +824,9 @@ main(int argc, char *argv[])
             continue;
         }
         if ((p = strchr(buf, '\n')) != NULL)
-            *p = '\0';		/* strip \n */
+            *p = '\0';      /* strip \n */
         if ((p = strchr(buf, '\r')) != NULL)
-            *p = '\0';		/* strip \r */
+            *p = '\0';      /* strip \r */
 
         debug("Got '%s' from Squid (length: %d).\n", buf, strlen(buf));
 
@@ -850,7 +835,7 @@ main(int argc, char *argv[])
             continue;
         }
         username = strtok(buf, " ");
-        for (n = 0; (group = strtok(NULL, " ")) != NULL; n++) {
+        for (n = 0; (group = strtok(NULL, " ")) != NULL; ++n) {
             rfc1738_unescape(group);
             groups[n] = group;
         }
@@ -872,3 +857,4 @@ main(int argc, char *argv[])
     }
     return 0;
 }
+
