@@ -1,39 +1,23 @@
 /*
- * AUTHOR: Francesco Chemolli <kinkie@kame.usr.dsi.unimi.it>
- * AUTHOR: Guido Serassio: <guido.serassio@acmeconsulting.it>
- * AUTHOR: Amos Jeffries <squid3@treenet.co.nz>
- *
- * * * * * * * * Legal stuff * * * * * * *
- *
- * (C) 2000 Francesco Chemolli <kinkie@kame.usr.dsi.unimi.it>,
- *   inspired by previous work by Andrew Doran <ad@interlude.eu.org>.
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
+/*
+ * Inspired by previous work by Andrew Doran <ad@interlude.eu.org>.
+ */
 #include "squid.h"
 
-#if HAVE_STRING_H
-#include <string.h>
-#endif
+#include <cstring>
 #if HAVE_STRINGS_H
 #include <strings.h>
 #endif
 
 #include "ntlmauth/ntlmauth.h"
-#include "util.h"		/* for base64-related stuff */
+#include "util.h"       /* for base64-related stuff */
 
 /* ************************************************************************* */
 /* DEBUG functions */
@@ -99,8 +83,6 @@ ntlm_validate_packet(const ntlmhdr * hdr, const int32_t type)
     return NTLM_ERR_NONE;
 }
 
-#define lstring_zero(s) s.str=NULL; s.l=-1;
-
 /**
  * Fetches a string from the authentication packet.
  * The lstring data-part may point to inside the packet itself or a temporary static buffer.
@@ -113,16 +95,15 @@ ntlm_validate_packet(const ntlmhdr * hdr, const int32_t type)
 lstring
 ntlm_fetch_string(const ntlmhdr *packet, const int32_t packet_size, const strhdr * str, const uint32_t flags)
 {
-    int16_t l;			/* length */
-    int32_t o;			/* offset */
     static char buf[NTLM_MAX_FIELD_LENGTH];
     lstring rv;
     char *d;
 
-    lstring_zero(rv);
+    rv.str = NULL;
+    rv.l = -1;
 
-    l = le16toh(str->len);
-    o = le32toh(str->offset);
+    int16_t l = le16toh(str->len);
+    int32_t o = le32toh(str->offset);
     // debug("ntlm_fetch_string(plength=%d,l=%d,o=%d)\n",packet_size,l,o);
 
     if (l < 0 || l > NTLM_MAX_FIELD_LENGTH || o + l > packet_size || o == 0) {
@@ -130,18 +111,19 @@ ntlm_fetch_string(const ntlmhdr *packet, const int32_t packet_size, const strhdr
         return rv;
     }
     rv.str = (char *)packet + o;
+    rv.l = 0;
     if ((flags & NTLM_NEGOTIATE_ASCII) == 0) {
         /* UNICODE string */
         unsigned short *s = (unsigned short *)rv.str;
         rv.str = d = buf;
 
-        for (l >>= 1; l; ++s, --l) {
-            unsigned short c = le16toh(*s);
+        for (uint32_t len = (l>>1); len; ++s, --len) {
+            uint16_t c = le16toh(*s);
             if (c > 254 || c == '\0') {
                 fprintf(stderr, "ntlmssp: bad unicode: %04x\n", c);
                 return rv;
             }
-            *d = c;
+            *d = static_cast<char>(c&0xFF);
             ++d;
             ++rv.l;
         }
@@ -173,14 +155,15 @@ ntlm_add_to_payload(const ntlmhdr *packet_hdr,
                     int *payload_length,
                     strhdr * hdr,
                     const char *toadd,
-                    const int toadd_length)
+                    const uint16_t toadd_length)
 {
     int l = (*payload_length);
     memcpy(payload + l, toadd, toadd_length);
 
     hdr->len = htole16(toadd_length);
     hdr->maxlen = htole16(toadd_length);
-    hdr->offset = htole32(l + payload - (char*)packet_hdr);
+    const off_t o = l + reinterpret_cast<const ntlmhdr *>(payload) - packet_hdr;
+    hdr->offset = htole32(o & 0xFFFFFFFF);
     (*payload_length) += toadd_length;
 }
 
@@ -202,12 +185,11 @@ void
 ntlm_make_nonce(char *nonce)
 {
     static unsigned hash;
-    int i;
-    int r = (int) rand();
+    uint32_t r = static_cast<uint32_t>(rand());
     r = (hash ^ r) + r;
 
-    for (i = 0; i < NTLM_NONCE_LEN; ++i) {
-        nonce[i] = r;
+    for (int i = 0; i < NTLM_NONCE_LEN; ++i) {
+        nonce[i] = static_cast<char>(r & 0xFF);
         r = (r >> 2) ^ r;
     }
     hash = r;
@@ -224,14 +206,17 @@ ntlm_make_challenge(ntlm_challenge *ch,
                     const uint32_t flags)
 {
     int pl = 0;
-    memset(ch, 0, sizeof(ntlm_challenge));	/* reset */
-    memcpy(ch->hdr.signature, "NTLMSSP", 8);		/* set the signature */
-    ch->hdr.type = htole32(NTLM_CHALLENGE);	/* this is a challenge */
+    memset(ch, 0, sizeof(ntlm_challenge));  /* reset */
+    memcpy(ch->hdr.signature, "NTLMSSP", 8);        /* set the signature */
+    ch->hdr.type = htole32(NTLM_CHALLENGE); /* this is a challenge */
     if (domain != NULL) {
-        ntlm_add_to_payload(&ch->hdr, ch->payload, &pl, &ch->target, domain, strlen(domain));
+        // silently truncate the domain if it exceeds 2^16-1 bytes.
+        // NTLM packets normally expect 2^8 bytes of domain.
+        const uint16_t dlen = strlen(domain) & 0xFFFF;
+        ntlm_add_to_payload(&ch->hdr, ch->payload, &pl, &ch->target, domain, dlen);
     }
     ch->flags = htole32(flags);
-    ch->context_low = 0;		/* check this out */
+    ch->context_low = 0;        /* check this out */
     ch->context_high = 0;
     memcpy(ch->challenge, challenge_nonce, challenge_nonce_len);
 }
@@ -246,10 +231,10 @@ ntlm_make_challenge(ntlm_challenge *ch,
  * this function will only insert data if the packet contains any. Otherwise
  * the buffers will be left untouched.
  *
- * \retval NTLM_ERR_NONE	username present, maybe also domain.
- * \retval NTLM_ERR_PROTOCOL	packet type is not an authentication packet.
- * \retval NTLM_ERR_LOGON	no username.
- * \retval NTLM_ERR_BLOB	domain field is apparently larger than the packet.
+ * \retval NTLM_ERR_NONE    username present, maybe also domain.
+ * \retval NTLM_ERR_PROTOCOL    packet type is not an authentication packet.
+ * \retval NTLM_ERR_LOGON   no username.
+ * \retval NTLM_ERR_BLOB    domain field is apparently larger than the packet.
  */
 int
 ntlm_unpack_auth(const ntlm_authenticate *auth, char *user, char *domain, const int32_t size)
@@ -290,3 +275,4 @@ ntlm_unpack_auth(const ntlm_authenticate *auth, char *user, char *domain, const
 
     return NTLM_ERR_NONE;
 }
+
