@@ -1,11 +1,13 @@
 /*
- * $Id$
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#include "config.h"
-#include "util.h"
-
-extern char **environ;
+#include "squid.h"
+#include "uudecode.h"
 
 /* aaaack but it's fast and const should make it shared text page. */
 const int pr2six[256] = {
@@ -68,3 +70,4 @@ uudecode(const char *bufcoded)
     bufplain[nbytesdecoded] = '\0';
     return bufplain;
 }
+
