@@ -1,3 +1,11 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #include "squid.h"
 #include "IpcIoDiskIOModule.h"
 #include "IpcIoIOStrategy.h"
@@ -18,7 +26,7 @@ IpcIoDiskIOModule::init()
 {}
 
 void
-IpcIoDiskIOModule::shutdown()
+IpcIoDiskIOModule::gracefulShutdown()
 {}
 
 DiskIOStrategy*
@@ -34,3 +42,4 @@ IpcIoDiskIOModule::type () const
 {
     return "IpcIo";
 }
+
