@@ -1,10 +1,20 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #ifndef SQUID_ADAPTATION__ACCESS_RULE_H
 #define SQUID_ADAPTATION__ACCESS_RULE_H
 
-#include "SquidString.h"
+#include "acl/forward.h"
 #include "adaptation/forward.h"
+#include "SquidString.h"
+
+#include <vector>
 
-class acl_access;
 class ConfigParser;
 
 namespace Adaptation
@@ -34,7 +44,7 @@ private:
     static Id LastId;
 };
 
-typedef Vector<Adaptation::AccessRule*> AccessRules;
+typedef std::vector<Adaptation::AccessRule*> AccessRules;
 AccessRules &AllRules();
 AccessRule *FindRule(const AccessRule::Id &id);
 AccessRule *FindRuleByGroupId(const String &groupId);
@@ -42,3 +52,4 @@ AccessRule *FindRuleByGroupId(const String &groupId);
 } // namespace Adaptation
 
 #endif /* SQUID_ADAPTATION__ACCESS_RULE_H */
+
