@@ -1,13 +1,14 @@
-
 /*
- * $Id$
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
 #ifndef SQUID_ASYNCCALLQUEUE_H
 #define SQUID_ASYNCCALLQUEUE_H
 
-#include "squid-old.h"
 #include "base/AsyncCall.h"
 
 //class AsyncCall;
@@ -38,3 +39,4 @@ private:
 };
 
 #endif /* SQUID_ASYNCCALLQUEUE_H */
+
