@@ -1,40 +1,20 @@
-
 /*
- * $Id$
- *
- * DEBUG: section 86    ESI processing
- * AUTHOR: Robert Collins
- *
- * SQUID Web Proxy Cache          http://www.squid-cache.org/
- * ----------------------------------------------------------
- *
- *  Squid is the result of efforts by numerous individuals from
- *  the Internet community; see the CONTRIBUTORS file for full
- *  details.   Many organizations have provided support for Squid's
- *  development; see the SPONSORS file for full details.  Squid is
- *  Copyrighted (C) 2001 by the Regents of the University of
- *  California; see the COPYRIGHT file for full details.  Squid
- *  incorporates software developed and/or copyrighted by other
- *  sources; see the CREDITS file for full details.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- ;  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
+/* DEBUG: section 86    ESI processing */
+
 #include "squid.h"
+#include "Debug.h"
 #include "esi/Expression.h"
+#include "profiler/Profiler.h"
+
+#include <cerrno>
+#include <cmath>
 
 /* stack precedence rules:
  * before pushing an operator onto the stack, the
@@ -54,8 +34,8 @@
 
 typedef struct _stackmember stackmember;
 
-typedef int evaluate (stackmember * stack, int *depth, int whereAmI,
-                      stackmember * candidate);
+typedef int evaluate(stackmember * stack, int *depth, int whereAmI,
+                     stackmember * candidate);
 
 typedef enum {
     ESI_EXPR_INVALID,
@@ -71,7 +51,7 @@ typedef enum {
     ESI_EXPR_LESSEQ,
     ESI_EXPR_MORE,
     ESI_EXPR_MOREEQ,
-    ESI_EXPR_EXPR			/* the result of an expr PRI 1 */
+    ESI_EXPR_EXPR           /* the result of an expr PRI 1 */
 } evaltype;
 
 typedef enum {
@@ -94,27 +74,27 @@ struct _stackmember {
     int precedence;
 };
 
-static void cleanmember (stackmember *);
-static void stackpop (stackmember * s, int *depth);
+static void cleanmember(stackmember *);
+static void stackpop(stackmember * s, int *depth);
 
 void
-cleanmember (stackmember * s)
+cleanmember(stackmember * s)
 {
     if (s->valuetype == ESI_EXPR_LITERAL
             && s->valuestored == ESI_LITERAL_STRING) {
-        safe_free (s->value.string);
+        safe_free(s->value.string);
         s->value.string = NULL;
     }
 
 }
 
 void
-stackpop (stackmember * s, int *depth)
+stackpop(stackmember * s, int *depth)
 {
     if (!(*depth)--)
         return;
 
-    cleanmember (&s[*depth]);
+    cleanmember(&s[*depth]);
 }
 
 static evaluate evalnegate;
@@ -130,14 +110,14 @@ static evaluate evalnotequals;
 static evaluate evalstartexpr;
 static evaluate evalendexpr;
 static evaluate evalexpr;
-static void dumpstack (stackmember * stack, int depth);
-static int addmember (stackmember * stack, int *stackdepth,
-                      stackmember * candidate);
-static int membercompare (stackmember a, stackmember b);
-static char const *trim (char const *s);
-static stackmember getsymbol (const char *s, char const **endptr);
-static void printliteral (stackmember s);
-static void printmember (stackmember s);
+static void dumpstack(stackmember * stack, int depth);
+static int addmember(stackmember * stack, int *stackdepth,
+                     stackmember * candidate);
+static int membercompare(stackmember a, stackmember b);
+static char const *trim(char const *s);
+static stackmember getsymbol(const char *s, char const **endptr);
+static void printliteral(stackmember s);
+static void printmember(stackmember s);
 
 /* -2 = failed to compate
  * -1 = a less than b
@@ -145,7 +125,7 @@ static void printmember (stackmember s);
  * 2 - a more than b
  */
 int
-membercompare (stackmember a, stackmember b)
+membercompare(stackmember a, stackmember b)
 {
     /* we can compare: sub expressions to sub expressions ,
      * literals to literals
@@ -163,7 +143,7 @@ membercompare (stackmember a, stackmember b)
             return 1;
     } else if (a.valuestored == ESI_LITERAL_STRING) {
         if (b.valuestored == ESI_LITERAL_STRING) {
-            int i =strcmp (a.value.string, b.value.string);
+            int i =strcmp(a.value.string, b.value.string);
 
             if (i < 0)
                 return -1;
@@ -174,7 +154,7 @@ membercompare (stackmember a, stackmember b)
             return 0;
         } else {
             /* TODO: numeric to string conversion ? */
-            debugs(86, 1, "strcmp with non-string");
+            debugs(86, DBG_IMPORTANT, "strcmp with non-string");
             return -2;
         }
     } else if (a.valuestored == ESI_LITERAL_FLOAT) {
@@ -194,7 +174,7 @@ membercompare (stackmember a, stackmember b)
                 return 1;
         } else {
             /* TODO: attempt numeric converson again? */
-            debugs(86, 1, "floatcomp with non float or int");
+            debugs(86, DBG_IMPORTANT, "floatcomp with non float or int");
             return -2;
         }
     } else if (a.valuestored == ESI_LITERAL_INT) {
@@ -214,7 +194,7 @@ membercompare (stackmember a, stackmember b)
                 return 1;
         } else {
             /* TODO: attempt numeric converson again? */
-            debugs(86, 1, "intcomp vs non float non int");
+            debugs(86, DBG_IMPORTANT, "intcomp vs non float non int");
             return -2;
         }
     }
@@ -223,8 +203,8 @@ membercompare (stackmember a, stackmember b)
 }
 
 /* return 0 on success, 1 on failure */
-int evalnegate
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalnegate(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     if (whereAmI != *depth - 2)
         /* invalid stack */
@@ -239,7 +219,7 @@ int evalnegate
 
     stack[whereAmI] = stack[(*depth)];
 
-    cleanmember (candidate);
+    cleanmember(candidate);
 
     if (stack[whereAmI].value.integral == 1)
         stack[whereAmI].value.integral = 0;
@@ -249,25 +229,24 @@ int evalnegate
     return 0;
 }
 
-int evalliteral
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalliteral(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
-    debugs(86, 1, "attempt to evaluate a literal");
+    debugs(86, DBG_IMPORTANT, "attempt to evaluate a literal");
     /* literals can't be evaluated */
     return 1;
 }
 
-int evalexpr
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalexpr(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
-    debugs(86, 1, "attempt to evaluate a sub-expression result");
+    debugs(86, DBG_IMPORTANT, "attempt to evaluate a sub-expression result");
     /* sub-scpr's can't be evaluated */
     return 1;
 }
 
-
-int evalor
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalor(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -287,15 +266,11 @@ int evalor
 
     rv = stack[whereAmI - 1].value.integral || stack[whereAmI + 1].value.integral;
 
-    if (rv == -2)
-        /* invalid comparison */
-        return 1;
+    stackpop(stack, depth);      /* arg rhs */
 
-    stackpop (stack, depth);      /* arg rhs */
+    stackpop(stack, depth);      /* me */
 
-    stackpop (stack, depth);      /* me */
-
-    stackpop (stack, depth);      /* arg lhs */
+    stackpop(stack, depth);      /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -310,15 +285,15 @@ int evalor
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
     return 0;
 }
 
-int evaland
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evaland(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -338,15 +313,11 @@ int evaland
 
     rv = stack[whereAmI - 1].value.integral && stack[whereAmI + 1].value.integral;
 
-    if (rv == -2)
-        /* invalid comparison */
-        return 1;
+    stackpop(stack, depth);      /* arg rhs */
 
-    stackpop (stack, depth);      /* arg rhs */
+    stackpop(stack, depth);      /* me */
 
-    stackpop (stack, depth);      /* me */
-
-    stackpop (stack, depth);      /* arg lhs */
+    stackpop(stack, depth);      /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -361,15 +332,15 @@ int evaland
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
     return 0;
 }
 
-int evallesseq
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evallesseq(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -382,17 +353,17 @@ int evallesseq
         /* invalid stack */
         return 1;
 
-    rv = membercompare (stack[whereAmI - 1], stack[whereAmI + 1]);
+    rv = membercompare(stack[whereAmI - 1], stack[whereAmI + 1]);
 
     if (rv == -2)
         /* invalid comparison */
         return 1;
 
-    stackpop (stack, depth);      /* arg rhs */
+    stackpop(stack, depth);      /* arg rhs */
 
-    stackpop (stack, depth);      /* me */
+    stackpop(stack, depth);      /* me */
 
-    stackpop (stack, depth);      /* arg lhs */
+    stackpop(stack, depth);      /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -407,18 +378,17 @@ int evallesseq
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
-    /*  debugs(86, 1, "?= " << srv.value.integral << " "); */
+    /*  debugs(86, DBG_IMPORTANT, "?= " << srv.value.integral << " "); */
     return 0;
 
-
 }
 
-int evallessthan
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evallessthan(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -431,17 +401,17 @@ int evallessthan
         /* invalid stack */
         return 1;
 
-    rv = membercompare (stack[whereAmI - 1], stack[whereAmI + 1]);
+    rv = membercompare(stack[whereAmI - 1], stack[whereAmI + 1]);
 
     if (rv == -2)
         /* invalid comparison */
         return 1;
 
-    stackpop (stack, depth);      /* arg rhs */
+    stackpop(stack, depth);      /* arg rhs */
 
-    stackpop (stack, depth);      /* me */
+    stackpop(stack, depth);      /* me */
 
-    stackpop (stack, depth);      /* arg lhs */
+    stackpop(stack, depth);      /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -456,18 +426,17 @@ int evallessthan
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
-    /* debugs(86, 1, "?= " << srv.value.integral << " "); */
+    /* debugs(86, DBG_IMPORTANT, "?= " << srv.value.integral << " "); */
     return 0;
 
-
 }
 
-int evalmoreeq
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalmoreeq(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -480,17 +449,17 @@ int evalmoreeq
         /* invalid stack */
         return 1;
 
-    rv = membercompare (stack[whereAmI - 1], stack[whereAmI + 1]);
+    rv = membercompare(stack[whereAmI - 1], stack[whereAmI + 1]);
 
     if (rv == -2)
         /* invalid comparison */
         return 1;
 
-    stackpop (stack, depth);      /* arg rhs */
+    stackpop(stack, depth);      /* arg rhs */
 
-    stackpop (stack, depth);      /* me */
+    stackpop(stack, depth);      /* me */
 
-    stackpop (stack, depth);      /* arg lhs */
+    stackpop(stack, depth);      /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -505,18 +474,17 @@ int evalmoreeq
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
-    /* debugs(86, 1, "?= " << srv.value.integral << " "); */
+    /* debugs(86, DBG_IMPORTANT, "?= " << srv.value.integral << " "); */
     return 0;
 
-
 }
 
-int evalmorethan
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalmorethan(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -529,17 +497,17 @@ int evalmorethan
         /* invalid stack */
         return 1;
 
-    rv = membercompare (stack[whereAmI - 1], stack[whereAmI + 1]);
+    rv = membercompare(stack[whereAmI - 1], stack[whereAmI + 1]);
 
     if (rv == -2)
         /* invalid comparison */
         return 1;
 
-    stackpop (stack, depth);	/* arg rhs */
+    stackpop(stack, depth); /* arg rhs */
 
-    stackpop (stack, depth);	/* me */
+    stackpop(stack, depth); /* me */
 
-    stackpop (stack, depth);	/* arg lhs */
+    stackpop(stack, depth); /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -554,18 +522,18 @@ int evalmorethan
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
-    /* debugs(86, 1, "?= " << srv.value.integral << " "); */
+    /* debugs(86, DBG_IMPORTANT, "?= " << srv.value.integral << " "); */
     return 0;
 
 }
 
 int
-evalequals (stackmember * stack, int *depth, int whereAmI,
-            stackmember * candidate)
+evalequals(stackmember * stack, int *depth, int whereAmI,
+           stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -578,17 +546,17 @@ evalequals (stackmember * stack, int *depth, int whereAmI,
         /* invalid stack */
         return 1;
 
-    rv = membercompare (stack[whereAmI - 1], stack[whereAmI + 1]);
+    rv = membercompare(stack[whereAmI - 1], stack[whereAmI + 1]);
 
     if (rv == -2)
         /* invalid comparison */
         return 1;
 
-    stackpop (stack, depth);	/* arg rhs */
+    stackpop(stack, depth); /* arg rhs */
 
-    stackpop (stack, depth);	/* me */
+    stackpop(stack, depth); /* me */
 
-    stackpop (stack, depth);	/* arg lhs */
+    stackpop(stack, depth); /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -603,16 +571,16 @@ evalequals (stackmember * stack, int *depth, int whereAmI,
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
-    /* debugs(86, 1, "?= " << srv.value.integral << " "); */
+    /* debugs(86, DBG_IMPORTANT, "?= " << srv.value.integral << " "); */
     return 0;
 }
 
-int evalnotequals
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalnotequals(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     int rv;
     stackmember srv;
@@ -625,17 +593,17 @@ int evalnotequals
         /* invalid stack */
         return 1;
 
-    rv = membercompare (stack[whereAmI - 1], stack[whereAmI + 1]);
+    rv = membercompare(stack[whereAmI - 1], stack[whereAmI + 1]);
 
     if (rv == -2)
         /* invalid comparison */
         return 1;
 
-    stackpop (stack, depth);	/* arg rhs */
+    stackpop(stack, depth); /* arg rhs */
 
-    stackpop (stack, depth);	/* me */
+    stackpop(stack, depth); /* me */
 
-    stackpop (stack, depth);	/* arg lhs */
+    stackpop(stack, depth); /* arg lhs */
 
     srv.valuetype = ESI_EXPR_EXPR;
 
@@ -650,18 +618,18 @@ int evalnotequals
     stack[(*depth)++] = srv;
 
     /* we're out of way, try adding now */
-    if (!addmember (stack, depth, candidate))
+    if (!addmember(stack, depth, candidate))
         /* Something wrong upstream */
         return 1;
 
-    /* debugs(86, 1, "?= " << srv.value.integral << " "); */
+    /* debugs(86, DBG_IMPORTANT, "?= " << srv.value.integral << " "); */
     return 0;
 }
 
-int evalstartexpr
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalstartexpr(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
-    /* debugs(86, 1, "?("); */
+    /* debugs(86, DBG_IMPORTANT, "?("); */
 
     if (whereAmI != *depth - 2)
         /* invalid stack */
@@ -675,20 +643,20 @@ int evalstartexpr
 
     stack[whereAmI] = stack[(*depth)];
 
-    cleanmember (candidate);
+    cleanmember(candidate);
 
     return 0;
 }
 
-int evalendexpr
-(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
+int
+evalendexpr(stackmember * stack, int *depth, int whereAmI, stackmember * candidate)
 {
     /* Can't evaluate ) brackets */
     return 1;
 }
 
 char const *
-trim (char const *s)
+trim(char const *s)
 {
     while (*s == ' ')
         ++s;
@@ -697,31 +665,33 @@ trim (char const *s)
 }
 
 stackmember
-getsymbol (const char *s, char const **endptr)
+getsymbol(const char *s, char const **endptr)
 {
     stackmember rv;
     char *end;
     char const *origs = s;
     /* trim whitespace */
-    s = trim (s);
-    rv.eval = NULL;		/* A literal */
+    s = trim(s);
+    rv.eval = NULL;     /* A literal */
     rv.valuetype = ESI_EXPR_INVALID;
     rv.valuestored = ESI_LITERAL_INVALID;
+    rv.precedence = 1; /* A literal */
 
     if (('0' <= *s && *s <= '9') || *s == '-') {
-        size_t length = strspn (s, "0123456789.");
+        size_t length = strspn(s, "0123456789.");
         char const *point;
 
-        if ((point = strchr (s, '.')) && point - s < (ssize_t)length) {
+        if ((point = strchr(s, '.')) && point - s < (ssize_t)length) {
             /* floating point */
-            rv.value.floating = strtod (s, &end);
+            errno=0; /* reset errno */
+            rv.value.floating = strtod(s, &end);
 
             if (s == end || errno) {
                 /* Couldn't convert to float */
-                debugs(86, 1, "failed to convert '" << s << "' to float ");
+                debugs(86, DBG_IMPORTANT, "failed to convert '" << s << "' to float ");
                 *endptr = origs;
             } else {
-                debugs (86,6, "found " << rv.value.floating << " of length " << end - s);
+                debugs(86,6, "found " << rv.value.floating << " of length " << end - s);
                 *endptr = end;
                 rv.eval = evalliteral;
                 rv.valuestored = ESI_LITERAL_FLOAT;
@@ -730,14 +700,15 @@ getsymbol (const char *s, char const **endptr)
             }
         } else {
             /* INT */
-            rv.value.integral = strtol (s, &end, 0);
+            errno=0; /* reset errno */
+            rv.value.integral = strtol(s, &end, 0);
 
             if (s == end || errno) {
                 /* Couldn't convert to int */
-                debugs(86, 1, "failed to convert '" << s << "' to int ");
+                debugs(86, DBG_IMPORTANT, "failed to convert '" << s << "' to int ");
                 *endptr = origs;
             } else {
-                debugs (86,6, "found " << rv.value.integral << " of length " << end - s);
+                debugs(86,6, "found " << rv.value.integral << " of length " << end - s);
                 *endptr = end;
                 rv.eval = evalliteral;
                 rv.valuestored = ESI_LITERAL_INT;
@@ -767,16 +738,16 @@ getsymbol (const char *s, char const **endptr)
             ++t;
 
         if (!*t) {
-            debugs(86, 1, "missing end \' in '" << s << "'");
+            debugs(86, DBG_IMPORTANT, "missing end \' in '" << s << "'");
             *endptr = origs;
         } else {
             *endptr = t + 1;
             /* Special case for zero length strings */
 
             if (t - s - 1)
-                rv.value.string = xstrndup (s + 1, t - s - 1);
+                rv.value.string = xstrndup(s + 1, t - s - 1);
             else
-                rv.value.string = static_cast<char *>(xcalloc (1,1));
+                rv.value.string = static_cast<char *>(xcalloc(1,1));
 
             rv.eval = evalliteral;
 
@@ -820,7 +791,7 @@ getsymbol (const char *s, char const **endptr)
             rv.precedence = 5;
             rv.eval = evalequals;
         } else {
-            debugs(86, 1, "invalid expr '" << s << "'");
+            debugs(86, DBG_IMPORTANT, "invalid expr '" << s << "'");
             *endptr = origs;
         }
     } else if ('<' == *s) {
@@ -851,7 +822,7 @@ getsymbol (const char *s, char const **endptr)
             rv.precedence = 5;
             rv.eval = evalmorethan;
         }
-    } else if (!strncmp (s, "false", 5)) {
+    } else if (!strncmp(s, "false", 5)) {
         debugs(86, 5, "getsymbol: found variable result 'false'");
         *endptr = s + 5;
         rv.valuetype = ESI_EXPR_EXPR;
@@ -859,7 +830,7 @@ getsymbol (const char *s, char const **endptr)
         rv.value.integral = 0;
         rv.precedence = 1;
         rv.eval = evalexpr;
-    } else if (!strncmp (s, "true", 4)) {
+    } else if (!strncmp(s, "true", 4)) {
         debugs(86, 5, "getsymbol: found variable result 'true'");
         *endptr = s + 4;
         rv.valuetype = ESI_EXPR_EXPR;
@@ -868,7 +839,7 @@ getsymbol (const char *s, char const **endptr)
         rv.precedence = 1;
         rv.eval = evalexpr;
     } else {
-        debugs(86, 1, "invalid expr '" << s << "'");
+        debugs(86, DBG_IMPORTANT, "invalid expr '" << s << "'");
         *endptr = origs;
     }
 
@@ -876,108 +847,108 @@ getsymbol (const char *s, char const **endptr)
 }
 
 void
-printliteral (stackmember s)
+printliteral(stackmember s)
 {
     switch (s.valuestored) {
 
     case ESI_LITERAL_INVALID:
-        debug(86, 1) ( " Invalid " );
+        old_debug(86, 1)( " Invalid " );
         break;
 
     case ESI_LITERAL_FLOAT:
-        debug (86,1) ("%f", s.value.floating);
+        old_debug(86,1)("%f", s.value.floating);
         break;
 
     case ESI_LITERAL_STRING:
-        debug (86,1) ("'%s'", s.value.string);
+        old_debug(86,1)("'%s'", s.value.string);
         break;
 
     case ESI_LITERAL_INT:
-        debug (86,1) ("%d", s.value.integral);
+        old_debug(86,1)("%d", s.value.integral);
         break;
 
     case ESI_LITERAL_BOOL:
-        debug (86,1)("%s",s.value.integral ? "true" : "false");
+        old_debug(86,1)("%s",s.value.integral ? "true" : "false");
     }
 }
 
 void
-printmember (stackmember s)
+printmember(stackmember s)
 {
     switch (s.valuetype) {
 
     case ESI_EXPR_INVALID:
-        debug (86,1) (" Invalid ");
+        old_debug(86,1)(" Invalid ");
         break;
 
     case ESI_EXPR_LITERAL:
-        printliteral (s);
+        printliteral(s);
         break;
 
     case ESI_EXPR_EXPR:
-        debug (86,1) ("%s", s.value.integral ? "true" : "false");
+        old_debug(86,1)("%s", s.value.integral ? "true" : "false");
         break;
 
     case ESI_EXPR_OR:
-        debug (86,1) ("|");
+        old_debug(86,1)("|");
         break;
 
     case ESI_EXPR_AND:
-        debug (86,1) ("&");
+        old_debug(86,1)("&");
         break;
 
     case ESI_EXPR_NOT:
-        debug (86,1) ("!");
+        old_debug(86,1)("!");
         break;
 
     case ESI_EXPR_START:
-        debug (86,1) ("(");
+        old_debug(86,1)("(");
         break;
 
     case ESI_EXPR_END:
-        debug (86,1) (")");
+        old_debug(86,1)(")");
         break;
 
     case ESI_EXPR_EQ:
-        debug (86,1) ("==");
+        old_debug(86,1)("==");
         break;
 
     case ESI_EXPR_NOTEQ:
-        debug (86,1) ("!=");
+        old_debug(86,1)("!=");
         break;
 
     case ESI_EXPR_LESS:
-        debug (86,1) ("<");
+        old_debug(86,1)("<");
         break;
 
     case ESI_EXPR_LESSEQ:
-        debug (86,1) ("<=");
+        old_debug(86,1)("<=");
         break;
 
     case ESI_EXPR_MORE:
-        debug (86,1) (">");
+        old_debug(86,1)(">");
         break;
 
     case ESI_EXPR_MOREEQ:
-        debug (86,1) (">=");
+        old_debug(86,1)(">=");
         break;
     }
 }
 
 void
-dumpstack (stackmember * stack, int depth)
+dumpstack(stackmember * stack, int depth)
 {
     int i;
 
     for (i = 0; i < depth; ++i)
-        printmember (stack[i]);
+        printmember(stack[i]);
 
     if (depth)
-        debug (86,1) ("\n");
+        old_debug(86,1)("\n");
 }
 
 int
-addmember (stackmember * stack, int *stackdepth, stackmember * candidate)
+addmember(stackmember * stack, int *stackdepth, stackmember * candidate)
 {
     if (candidate->valuetype != ESI_EXPR_LITERAL && *stackdepth > 1) {
         /* !(!(a==b))) is why thats safe */
@@ -989,12 +960,12 @@ addmember (stackmember * stack, int *stackdepth, stackmember * candidate)
 
             if (stack[*stackdepth - 2].valuetype == ESI_EXPR_LITERAL ||
                     stack[*stackdepth - 2].valuetype == ESI_EXPR_INVALID ||
-                    stack[*stackdepth - 2].eval (stack, stackdepth,
-                                                 *stackdepth - 2, candidate)) {
+                    stack[*stackdepth - 2].eval(stack, stackdepth,
+                                                *stackdepth - 2, candidate)) {
                 /* cleanup candidate and stack */
-                dumpstack (stack, *stackdepth);
-                cleanmember (candidate);
-                debugs(86, 1, "invalid expression");
+                dumpstack(stack, *stackdepth);
+                cleanmember(candidate);
+                debugs(86, DBG_IMPORTANT, "invalid expression");
                 return 0;
             }
         } else {
@@ -1007,7 +978,7 @@ addmember (stackmember * stack, int *stackdepth, stackmember * candidate)
 }
 
 int
-ESIExpression::Evaluate (char const *s)
+ESIExpression::Evaluate(char const *s)
 {
     stackmember stack[20];
     int stackdepth = 0;
@@ -1015,12 +986,12 @@ ESIExpression::Evaluate (char const *s)
     PROF_start(esiExpressionEval);
 
     while (*s) {
-        stackmember candidate = getsymbol (s, &end);
+        stackmember candidate = getsymbol(s, &end);
 
         if (candidate.valuetype != ESI_EXPR_INVALID) {
-            assert (s != end);
+            assert(s != end);
 
-            if (!addmember (stack, &stackdepth, &candidate)) {
+            if (!addmember(stack, &stackdepth, &candidate)) {
                 PROF_stop(esiExpressionEval);
                 return 0;
             }
@@ -1028,7 +999,7 @@ ESIExpression::Evaluate (char const *s)
             s = end;
         } else {
             assert (s == end);
-            debugs(86, 1, "failed parsing expression");
+            debugs(86, DBG_IMPORTANT, "failed parsing expression");
             PROF_stop(esiExpressionEval);
             return 0;
         }
@@ -1040,9 +1011,9 @@ ESIExpression::Evaluate (char const *s)
         rv.precedence = 0;
 
         if (stack[stackdepth - 2].
-                eval (stack, &stackdepth, stackdepth - 2, &rv)) {
+                eval(stack, &stackdepth, stackdepth - 2, &rv)) {
             /* special case - leading operator failed */
-            debugs(86, 1, "invalid expression");
+            debugs(86, DBG_IMPORTANT, "invalid expression");
             PROF_stop(esiExpressionEval);
             return 0;
         }
@@ -1055,11 +1026,12 @@ ESIExpression::Evaluate (char const *s)
     }
 
     /* if we hit here, we think we have a valid result */
-    assert (stackdepth == 1);
+    assert(stackdepth == 1);
 
-    assert (stack[0].valuetype == ESI_EXPR_EXPR);
+    assert(stack[0].valuetype == ESI_EXPR_EXPR);
 
     PROF_stop(esiExpressionEval);
 
     return stack[0].value.integral ? 1 : 0;
 }
+
