@@ -1,4 +1,11 @@
-#define SQUID_UNIT_TEST 1
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #define SQUID_HELPER 1
 
 #include "squid.h"
@@ -15,7 +22,9 @@ void
 testIcmp::testChecksum()
 {
     stubIcmp icmp;
-    short unsigned int buf[10] = {htons(1),htons(2),htons(3),htons(4),htons(5),htons(6),htons(7),htons(8),htons(9), htons(10)};
+    uint16_t buf[10], tmpval;
+    for (tmpval=0; tmpval < 10; ++tmpval)
+        buf[tmpval]=htons(1+tmpval);
 
     // NULL data
     CPPUNIT_ASSERT_EQUAL((int)htons(0xffff), icmp.testChecksum(NULL,0));
@@ -106,3 +115,4 @@ testIcmp::testHops()
 }
 
 #endif /* USE_ICMP */
+
