@@ -1,8 +1,13 @@
 /*
- * DEBUG: section 54    Interprocess Communication
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
+/* DEBUG: section 54    Interprocess Communication */
+
 #include "squid.h"
 #include "base/AsyncJobCalls.h"
 #include "base/TextException.h"
@@ -19,8 +24,8 @@ Ipc::Forwarder::RequestsMap Ipc::Forwarder::TheRequestsMap;
 unsigned int Ipc::Forwarder::LastRequestId = 0;
 
 Ipc::Forwarder::Forwarder(Request::Pointer aRequest, double aTimeout):
-        AsyncJob("Ipc::Forwarder"),
-        request(aRequest), timeout(aTimeout)
+    AsyncJob("Ipc::Forwarder"),
+    request(aRequest), timeout(aTimeout)
 {
     debugs(54, 5, HERE);
 }
@@ -59,7 +64,7 @@ Ipc::Forwarder::start()
         handleError();
     }
 
-    SendMessage(coordinatorAddr, message);
+    SendMessage(Ipc::Port::CoordinatorAddr(), message);
     eventAdd("Ipc::Forwarder::requestTimedOut", &Forwarder::RequestTimedOut,
              this, timeout, 0, false);
 }
@@ -177,3 +182,4 @@ Ipc::Forwarder::HandleRemoteAck(unsigned int requestId)
     if (call != NULL)
         ScheduleCallHere(call);
 }
+
