@@ -1,14 +1,21 @@
-#define SQUID_UNIT_TEST 1
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #include "squid.h"
 
 #include <cppunit/TestAssert.h>
 
-#include "testEvent.h"
-#include "event.h"
 #include "base/AsyncCallQueue.h"
 #include "CapturingStoreEntry.h"
+#include "event.h"
 #include "Mem.h"
-
+#include "stat.h"
+#include "testEvent.h"
 
 CPPUNIT_TEST_SUITE_REGISTRATION( testEvent );
 
@@ -30,7 +37,6 @@ testEvent::testCreate()
     EventScheduler scheduler = EventScheduler();
 }
 
-
 /* Helper for tests - an event which records the number of calls it received. */
 
 struct CalledEvent {
@@ -87,7 +93,7 @@ testEvent::testDump()
     /* loop over the strings, showing exactly where they differ (if at all) */
     printf("Actual Text:\n");
     /* TODO: these should really be just [] lookups, but String doesn't have those here yet. */
-    for ( unsigned int i = 0; i < anEntry->_appended_text.size(); i++) {
+    for ( unsigned int i = 0; i < anEntry->_appended_text.size(); ++i) {
         CPPUNIT_ASSERT( expect[i] );
         CPPUNIT_ASSERT( anEntry->_appended_text[i] );
 
@@ -150,3 +156,4 @@ testEvent::testSingleton()
     EventScheduler *scheduler = dynamic_cast<EventScheduler *>(EventScheduler::GetInstance());
     CPPUNIT_ASSERT(NULL != scheduler);
 }
+
