@@ -1,3 +1,11 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 /*
  * StatHist unit test
  */
@@ -7,13 +15,13 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-
 class testStatHist : public CPPUNIT_NS::TestFixture
 {
     CPPUNIT_TEST_SUITE( testStatHist );
     CPPUNIT_TEST( testStatHistBaseEquality );
     CPPUNIT_TEST( testStatHistBaseAssignment );
     CPPUNIT_TEST( testStatHistLog );
+    CPPUNIT_TEST( testStatHistSum );
     CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -22,6 +30,8 @@ protected:
     void testStatHistBaseEquality();
     void testStatHistBaseAssignment();
     void testStatHistLog();
+    void testStatHistSum();
 };
 
 #endif /* TESTSTATHIST_H_ */
+
